@@ -4,6 +4,7 @@ import os
 import plotly.express as px
 import plotly.graph_objs as go
 from dateutil.parser import parse
+import numpy as np
 
 class dataprocessing:
     
@@ -20,14 +21,14 @@ class dataprocessing:
         print("   - Usage: remove_rows(data_frame, num_rows_to_remove)")
         print("   - Example: remove_rows(df, 2)")
 
-        print("\n3. aggregate_daily_to_wc")
+        print("\n3. aggregate_daily_to_wc_long")
         print("   - Description: Aggregates daily data into weekly data, grouping and summing specified columns, starting on a specified day of the week.")
-        print("   - Usage: aggregate_daily_to_wc(df, date_column, group_columns, sum_columns, wc, aggregation='sum', include_totals=False)")
-        print("   - Example: aggregate_daily_to_wc(df, 'date', ['platform'], ['cost', 'impressions', 'clicks'], 'mon', 'average', True)")
+        print("   - Usage: aggregate_daily_to_wc_long(df, date_column, group_columns, sum_columns, wc, aggregation='sum')")
+        print("   - Example: aggregate_daily_to_wc_long(df, 'date', ['platform'], ['cost', 'impressions', 'clicks'], 'mon', 'average')")
 
         print("\n4. convert_monthly_to_daily")
         print("   - Description: Converts monthly data in a DataFrame to daily data by expanding and dividing the numeric values.")
-        print("   - Usage: convert_monthly_to_daily(df, date_column)")
+        print("   - Usage: convert_monthly_to_daily(df, date_column, divide)")
         print("   - Example: convert_monthly_to_daily(df, 'date')")
 
         print("\n5. plot_two")
@@ -71,10 +72,10 @@ class dataprocessing:
         print("    - Usage: merge_new_and_old(old_df, old_col, new_df, new_col, cutoff_date, date_col_name='OBS')")
         print("    - Example: merge_new_and_old(df1, 'old_col', df2, 'new_col', '2023-01-15')")
 
-        print("\n13. merge_dataframes_on_column")
+        print("\n13. merge_dataframes_on_date")
         print("    - Description: Merge a list of DataFrames on a common column.")
-        print("    - Usage: merge_dataframes_on_column(dataframes, common_column='OBS', merge_how='outer')")
-        print("    - Example: merge_dataframes_on_column([df1, df2, df3], common_column='OBS', merge_how='outer')")
+        print("    - Usage: merge_dataframes_on_date(dataframes, common_column='OBS', merge_how='outer')")
+        print("    - Example: merge_dataframes_on_date([df1, df2, df3], common_column='OBS', merge_how='outer')")
 
         print("\n14. merge_and_update_dfs")
         print("    - Description: Merges two dataframes on a key column, updates the first dataframe's columns with the second's where available, and returns a dataframe sorted by the key column.")
@@ -101,6 +102,10 @@ class dataprocessing:
         print("    - Usage: classify_within_column(df, col_name, to_find_dict, if_not_in_country_dict='Other')")
         print("    - Example: classify_within_column(df, 'campaign', {'uk_': 'uk'}, 'other')")
 
+        print("\n19. aggregate_daily_to_wc_wide")
+        print("   - Description: Aggregates daily data into weekly data, grouping and summing specified columns, starting on a specified day of the week.")
+        print("   - Usage: aggregate_daily_to_wc_wide(df, date_column, group_columns, sum_columns, wc, aggregation='sum', include_totals=False)")
+        print("   - Example: aggregate_daily_to_wc_wide(df, 'date', ['platform'], ['cost', 'impressions', 'clicks'], 'mon', 'average', True)")
 
     def get_wd_levels(self, levels):
         """
@@ -156,7 +161,7 @@ class dataprocessing:
 
         return modified_data_frame
     
-    def aggregate_daily_to_wc_long(self, df : pd.DataFrame, date_column : str, group_columns : list[str], sum_columns : list[str], wc : str = 'sun', aggregation : str = 'sum'):
+    def aggregate_daily_to_wc_long(self, df : pd.DataFrame, date_column : str, group_columns : list[str], sum_columns : list[str], wc : str = 'sun', aggregation : str = 'sum') -> pd.DataFrame:
         """
         Aggregates daily data into weekly data, starting on a specified day of the week, 
         and groups the data by additional specified columns. It aggregates specified numeric columns 
@@ -182,7 +187,7 @@ class dataprocessing:
         - pandas DataFrame
             A new DataFrame with weekly aggregated data. The index is reset,
             and columns represent the grouped and aggregated metrics. The DataFrame 
-            is in wide format, with separate columns for each combination of 
+            is in long format, with separate columns for each combination of 
             grouped metrics.
         """
 
@@ -217,15 +222,10 @@ class dataprocessing:
         # Rename 'week_start' column to 'OBS'
         grouped = grouped.rename(columns={'week_start': 'OBS'})
 
-        # Reset the index of the final DataFrame
-        grouped.reset_index(inplace = True)
-
         return grouped
     
-    def aggregate_daily_to_wc_wide(self, df : pd.DataFrame, date_column : str, group_columns : list[str], sum_columns : list[str], wc : str = 'sun', aggregation : str = 'sum', 
-                                   include_totals : bool = False):
-        
-                """
+    def aggregate_daily_to_wc_wide(self, df : pd.DataFrame, date_column : str, group_columns : list[str], sum_columns : list[str], wc : str = 'sun', aggregation : str = 'sum', include_totals : bool = False) -> pd.DataFrame:
+        """
         Aggregates daily data into weekly data, starting on a specified day of the week, 
         and groups the data by additional specified columns. It aggregates specified numeric columns 
         by summing, averaging, or counting them, and pivots the data to create separate columns for each combination 
@@ -289,7 +289,7 @@ class dataprocessing:
 
         return wide_df
     
-    def convert_monthly_to_daily(self, df, date_column):
+    def convert_monthly_to_daily(self, df, date_column, divide = True):
         """
         Convert a DataFrame with monthly data to daily data.
         This function takes a DataFrame and a date column, then it expands each
@@ -297,6 +297,7 @@ class dataprocessing:
 
         :param df: DataFrame with monthly data.
         :param date_column: The name of the column containing the date.
+        :param divide: boolean divide by the number of days in a month (default True)
         :return: A new DataFrame with daily data.
         """
 
@@ -319,8 +320,10 @@ class dataprocessing:
                 # Divide each numeric value by the number of days in the month
                 for col in df.columns:
                     if pd.api.types.is_numeric_dtype(df[col]) and col != date_column:
-                        daily_row[col] = row[col] / num_days
-
+                        if divide == True:
+                            daily_row[col] = row[col] / num_days
+                        else: 
+                            daily_row[col] = row[col]
                 daily_records.append(daily_row)
 
         # Convert the list of daily records into a DataFrame
@@ -524,7 +527,9 @@ class dataprocessing:
         for df in dataframes[1:]:
             merged_df = pd.merge(merged_df, df, on=common_column, how=merge_how)
 
-        merged_df[common_column] = pd.to_datetime(merged_df[common_column])
+        # Check if the common column is of datetime dtype
+        if merged_df[common_column].dtype == 'datetime64[ns]':
+            merged_df[common_column] = pd.to_datetime(merged_df[common_column])
         merged_df = merged_df.sort_values(by=common_column)
         merged_df = merged_df.fillna(0)
         
@@ -671,4 +676,4 @@ class dataprocessing:
         # Apply the inner function to the specified column and create a new column with the results
         df[col_name + '_mapping'] = df[col_name].apply(find_word_in_string)
         
-        return df
+        return df
\ No newline at end of file
